@@ -42,6 +42,7 @@ from neuro_cli.formatters.utils import (
     uri_formatter,
 )
 from neuro_cli.parse_utils import parse_timedelta
+from neuro_cli.utils import format_size
 
 from .const import EX_OSFILE
 from .formatters.blob_storage import (
@@ -180,7 +181,7 @@ async def mkbucket(
     metavar="AWS_ACCESS_KEY_ID",
     help="AWS access_key_id to use to access the bucket. "
     " Required when PROVIDER is 'aws'",
-    default=False,
+    default=None,
 )
 @option(
     "--aws-secret-access-key",
@@ -188,7 +189,7 @@ async def mkbucket(
     metavar="AWS_SECRET_ACCESS_KEY",
     help="AWS secret_access_key to use to access the bucket. "
     "Required when PROVIDER is 'aws'",
-    default=False,
+    default=None,
 )
 @option(
     "--aws-region-name",
@@ -213,7 +214,7 @@ async def mkbucket(
     help="Azure account url. Usually it has following format: "
     "https://<account_id>.blob.core.windows.net "
     "Required when PROVIDER is 'azure'",
-    default=False,
+    default=None,
 )
 @option(
     "--azure-storage-sas-token",
@@ -221,7 +222,7 @@ async def mkbucket(
     metavar="AZURE_SAS",
     help="Azure shared access signature token that grants access to imported bucket. "
     "Either this or AZURE_STORAGE_CREDENTIAL is required when PROVIDER is 'azure'",
-    default=False,
+    default=None,
 )
 @option(
     "--azure-storage-credential",
@@ -229,7 +230,7 @@ async def mkbucket(
     metavar="AZURE_STORAGE_CREDENTIAL",
     help="Azure storage credential that grants access to imported bucket. "
     "Either this or AZURE_SAS is required when PROVIDER is 'azure'",
-    default=False,
+    default=None,
 )
 @option(
     "--gcp-sa-credential",
@@ -238,7 +239,7 @@ async def mkbucket(
     help="GCP service account credential in form of base64 encoded json "
     "string that grants access to imported bucket. "
     "Required when PROVIDER is 'gcp'",
-    default=False,
+    default=None,
 )
 async def importbucket(
     root: Root,
@@ -340,6 +341,37 @@ async def statbucket(
         root.print(bucket_fmtr(bucket_obj))
 
 
+@command()
+@option(
+    "--cluster",
+    type=CLUSTER,
+    help="Look on a specified cluster (the current cluster by default).",
+)
+@argument("bucket", type=BUCKET)
+async def du(root: Root, cluster: Optional[str], bucket: str) -> None:
+    """
+    Get storage usage for BUCKET.
+    """
+    bucket_obj = await root.client.buckets.get(bucket, cluster_name=cluster)
+
+    base_str = f"Calculating bucket {bucket_obj.name or bucket_obj.id} disk usage"
+
+    with root.status(base_str) as status:
+        async with root.client.buckets.get_disk_usage(
+            bucket_obj.id, cluster
+        ) as usage_it:
+            async for usage in usage_it:
+                status.update(
+                    f"{base_str}: total size {format_size(usage.total_bytes)}, "
+                    f"objects count {usage.object_count}"
+                )
+    root.print(
+        f"Bucket {bucket_obj.name or bucket_obj.id} disk usage:\n"
+        f"Total size: {format_size(usage.total_bytes)}\n"
+        f"Objects count: {usage.object_count}"
+    )
+
+
 @command()
 @option(
     "--cluster",
@@ -1001,3 +1033,4 @@ blob_storage.add_command(ls)
 blob_storage.add_command(glob)
 blob_storage.add_command(rm)
 blob_storage.add_command(sign_url)
+blob_storage.add_command(du)
