@@ -51,7 +51,6 @@ from .root import Root
 from .topics import topics
 from .utils import (
     Context,
-    DeprecatedGroup,
     Group,
     alias,
     argument,
@@ -364,6 +363,8 @@ def print_options(
 @option(
     "--disable-pypi-version-check",
     is_flag=True,
+    envvar="NEURO_CLI_DISABLE_PYPI_VERSION_CHECK",
+    show_envvar=True,
     help="Don't periodically check PyPI to determine whether a new version of "
     "Neuro Platform CLI is available for download.",
 )
@@ -509,8 +510,6 @@ cli.add_command(secrets.secret)
 cli.add_command(disks.disk)
 cli.add_command(service_accounts.service_account)
 
-cli.add_command(DeprecatedGroup(storage.storage, name="store", hidden=True))
-
 # shortcuts
 cli.add_command(job.run)
 cli.add_command(alias(job.ls, "ps", help=job.ls.help, deprecated=False))
